package journal.action;

import java.io.FileOutputStream;
import java.io.PrintStream;

import journal.reader.DataJournalEntry;
import journal.reader.DeleteJournalEntry;
import journal.reader.NoteJournalEntry;
import journal.reader.Options;
import journal.reader.TransactionJournalEntry;

public abstract class BaseAction implements Action 
{
	@Override
	public void start() throws Exception {
	}
	
	@Override
	public void setDefaultOptions(Options options) {
		this.options = options;
		this.out = options.getOutputStream();

		options.setOptionName(this.getClass().getName(), "outputFile", "", 
				new Options.OptionSetter() {
					public void set(String key, String value) {
						if( outputFile != "" ) {
							out.close();
						}
						outputFile = value;
						try {
							out = new PrintStream(new FileOutputStream(outputFile));
						}
						catch (Exception e) {
							System.err.println("Cannot open file : " + outputFile);
							e.printStackTrace(System.err);
							System.exit(1);
						}
					}
				}
		);
	}
	
	@Override
	public void help() {
	}
	
	@Override
	public void finish() throws Exception  {
		if( outputFile != "" ) {
			out.close();
		}
	}
	
	@Override
	public String[] parseArgs(String[] args) {
		return args;
	}

	@Override
	public void putValue(DataJournalEntry entry) throws Exception {
		// empty implementation
	}
	@Override
	public void replaceValue(DataJournalEntry entry) throws Exception {
		// empty implementation
	}
	@Override
	public void deleteValue(DataJournalEntry entry) throws Exception {
		// empty implementation
	}
	@Override
	public void verifyValue(DataJournalEntry entry) throws Exception {
		// empty implementation
	}
	@Override
	public void commitMarker(TransactionJournalEntry entry) throws Exception {
		// empty implementation
	}
	@Override
	public void flushMarker(TransactionJournalEntry entry) throws Exception {
		// empty implementation
	}
	@Override
	public void journalMarker(NoteJournalEntry entry) throws Exception {
		// empty implementation
	}
	@Override
	public void deleteMarker(DeleteJournalEntry entry) throws Exception {
		// empty implementation
	}
	
	protected String outputFile = "";
	protected PrintStream out;
	protected Options options;
}
